import { RouteRecordRaw } from "vue-router";
import Layout from "@/Layout/index.vue";
const routes: RouteRecordRaw[] = [
  {
    path: "/",
    name: "Login",
    component: () => import("@/views/Login/index.vue"),
  },
  {
    path: "/layout",
    name: "Layout",
    component: Layout,
    meta: {
      title: "首页",
    },
    children: [
      {
        path: "cur-exam",
        name: "CurExam",
        component: () => import("@/views/CurExam/index.vue"),
        meta: {
          title: "当前考试信息",
        },
      },
      {
        path: "base-data-config",
        name: "BaseDataConfig",
        component: () => import("@/views/BaseDataConfig/index.vue"),
        meta: {
          title: "基础数据配置",
        },
      },
      {
        path: "scan-manage",
        name: "ScanManage",
        component: () => import("@/views/ScanManage/index.vue"),
        meta: {
          title: "扫描管理",
        },
      },
      {
        path: "review",
        name: "Review",
        component: () => import("@/views/Review/index.vue"),
        meta: {
          title: "复核校验",
        },
      },
      {
        path: "recognize-check",
        name: "RecognizeCheck",
        component: () => import("@/views/RecognizeCheck/index.vue"),
        meta: {
          title: "识别对照",
        },
        children: [
          {
            path: "recognize-arbitrate/:groupId",
            name: "RecognizeArbitrate",
            component: () =>
              import("@/views/RecognizeCheck/RecognizeArbitrate.vue"),
            meta: {
              title: "仲裁",
            },
          },
        ],
      },
      {
        path: "absent-check",
        name: "AbsentCheck",
        component: () => import("@/views/AbsentCheck/index.vue"),
        meta: {
          title: "缺考校验",
        },
      },
      {
        path: "data-check",
        name: "DataCheck",
        component: () => import("@/views/DataCheck/index.vue"),
        meta: {
          title: "数据检查",
        },
      },
      // 图片检查
      {
        path: "image-check",
        name: "ImageCheck",
        component: () => import("@/views/ImageCheck/index.vue"),
        meta: {
          title: "图片检查",
        },
        children: [
          {
            path: "image-failed/:examId/:subjectCode",
            name: "ImageFailed",
            component: () => import("@/views/ImageCheck/ImageFailed.vue"),
            meta: {
              title: "图片异常",
            },
          },
        ],
      },
      // 结果导出
      {
        path: "result-export",
        name: "ResultExport",
        component: () => import("@/views/ResultExport/index.vue"),
        meta: {
          title: "结果导出",
        },
      },
      // 审核
      {
        path: "audit",
        name: "Audit",
        component: () => import("@/views/Audit/Main/index.vue"),
        meta: {
          title: "审核",
        },
      },
      // 实时审核
      {
        path: "intime-audit",
        name: "IntimeAudit",
        component: () => import("@/views/Audit/Intime/index.vue"),
        meta: {
          title: "实时审核",
        },
      },
      // 审核员复核校验
      {
        path: "review-audit",
        name: "ReviewAudit",
        component: () => import("@/views/Audit/Review/index.vue"),
        meta: {
          title: "复核校验",
        },
      },
      // 审核员图片抽查
      {
        path: "image-check-audit",
        name: "ImageCheckAudit",
        component: () => import("@/views/Audit/ImageCheck/index.vue"),
        meta: {
          title: "图片抽查",
        },
      },
    ],
  },
];
export default routes;
